==> owncloud-4.5.7.tgz: owncloud/apps/calendar/l10n/th_TH.php <==
<?php $TRANSLATIONS = array(
"Not all calendars are completely cached" => "ไม่ใช่ปฏิทินทั้งหมดที่จะถูกจัดเก็บข้อมูลไว้ในหน่วยความจำแคชอย่างสมบูรณ์",
"Everything seems to be completely cached" => "ทุกสิ่งทุกอย่างได้ถูกเก็บเข้าไปไว้ในหน่วยความจำแคชอย่างสมบูรณ์แล้ว",
"No calendars found." => "ไม่พบปฏิทินที่ต้องการ",
"No events found." => "ไม่พบกิจกรรมที่ต้องการ",
"Wrong calendar" => "ปฏิทินไม่ถูกต้อง",
"The file contained either no events or all events are already saved in your calendar." => "ไฟล์ดังกล่าวบรรจุข้อมูลกิจกรรมที่มีอยู่แล้วในปฏิทินของคุณ",
"events has been saved in the new calendar" => "กิจกรรมได้ถูกบันทึกไปไว้ในปฏิทินที่สร้างขึ้นใหม่แล้ว",
"Import failed" => "การนำเข้าข้อมูลล้มเหลว",
"events has been saved in your calendar" => "กิจกรรมได้ถูกบันทึกเข้าไปไว้ในปฏิทินของคุณแล้ว",
"New Timezone:" => "สร้างโซนเวลาใหม่:",
"Timezone changed" => "โซนเวลาถูกเปลี่ยนแล้ว",
"Invalid request" => "คำร้องขอไม่ถูกต้อง",
"Calendar" => "ปฏิทิน",
"Deletion failed" => "การลบทิ้งล้มเหลว",
"ddd d MMMM[ yyyy]{ -[ddd d] MMMM yyyy}" => "ddd d MMMM[ yyyy]{ -[ddd d] MMMM yyyy}",
"ddd d MMMM[ yyyy] HH:mm{ -[ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ yyyy] HH:mm{ -[ ddd d MMMM yyyy] HH:mm}",
"user" => "ผู้ใช้งาน",
"group" => "กลุ่มผู้ใช้งาน",
"Editable" => "สามารถแก้ไขได้",
"Shareable" => "สามารถแชร์ข้อมูลได้",
"Deletable" => "สามารถลบทิ้งได้",
"ddd" => "ddd",
"ddd M/d" => "ddd M/d",
"dddd M/d" => "dddd M/d",
"MMMM yyyy" => "MMMM yyyy",
"MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}" => "MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}",
"dddd, MMM d, yyyy" => "dddd, MMM d, yyyy",
"Birthday" => "วันเกิด",
"Business" => "ธุรกิจ",
"Call" => "โทรติดต่อ",
"Clients" => "ลูกค้า",
"Deliverer" => "จัดส่ง",
"Holidays" => "วันหยุด",
"Ideas" => "ไอเดีย",
"Journey" => "การเดินทาง",
"Jubilee" => "งานเลี้ยง",
"Meeting" => "นัดประชุม",
"Other" => "อื่นๆ",
"Personal" => "ส่วนตัว",
"Projects" => "โครงการ",
"Questions" => "คำถาม",
"Work" => "งาน",
"by" => "โดย",
"unnamed" => "ไม่มีชื่อ",
"You do not have the permissions to update this calendar." => "คุณไม่ได้รับสิทธิ์ให้อัพเดทปฏิทินนี้",
"You do not have the permissions to delete this calendar." => "คุณไม่ได้รับสิทธิ์ให้ลบปฏิทินนี้ทิ้งไป",
"You do not have the permissions to add to this calendar." => "คุณไม่ได้รับสิทธิ์ให้เพิ่มปฏิทินนี้",
"New Calendar" => "สร้างปฏิทินใหม่",
"You do not have the permissions to add events to this calendar." => "คุณไม่ได้รับสิทธิ์ให้เพิ่มกิจกรรมเข้าไปในปฏิทินนี้",
"You do not have the permissions to edit this event." => "คุณไม่ได้รับสิทธิ์ให้แก้ไขกิจกรรมนี้",
"You do not have the permissions to delete this event." => "คุณไม่ได้รับสิทธิ์ให้ลบกิจกรรมนี้",
"Does not repeat" => "ไม่ต้องทำซ้ำ",
"Daily" => "รายวัน",
"Weekly" => "รายสัปดาห์",
"Every Weekday" => "ทุกวันหยุด",
"Bi-Weekly" => "รายปักษ์",
"Monthly" => "รายเดือน",
"Yearly" => "รายปี",
"never" => "ไม่ต้องเลย",
"by occurrences" => "ตามจำนวนที่ปรากฏ",
"by date" => "ตามวันที่",
"by monthday" => "จากเดือน",
"by weekday" => "จากสัปดาห์",
"Monday" => "วันจันทร์",
"Tuesday" => "วันอังคาร",
"Wednesday" => "วันพุธ",
"Thursday" => "วันพฤหัสบดี",
"Friday" => "วันศุกร์",
"Saturday" => "วันเสาร์",
"Sunday" => "วันอาทิตย์",
"events week of month" => "สัปดาห์ที่มีกิจกรรมของเดือน",
"first" => "ลำดับแรก",
"second" => "ลำดับที่สอง",
"third" => "ลำดับที่สาม",
"fourth" => "ลำดับที่สี่",
"fifth" => "ลำดับที่ห้า",
"last" => "ลำดับสุดท้าย",
"January" => "มกราคม",
"February" => "กุมภาพันธ์",
"March" => "มีนาคม",
"April" => "เมษายน",
"May" => "พฤษภาคม",
"June" => "มิถุนายน",
"July" => "กรกฏาคม",
"August" => "สิงหาคม",
"September" => "กันยายน",
"October" => "ตุลาคม",
"November" => "พฤศจิกายน",
"December" => "ธันวาคม",
"by events date" => "ตามวันที่จัดกิจกรรม",
"by yearday(s)" => "ของเมื่อวานนี้",
"by weeknumber(s)" => "จากหมายเลขของสัปดาห์",
"by day and month" => "ตามวันและเดือน",
"Date" => "วันที่",
"Cal." => "คำนวณ",
"Sun." => "อา.",
"Mon." => "จ.",
"Tue." => "อ.",
"Wed." => "พ.",
"Thu." => "พฤ.",
"Fri." => "ศ.",
"Sat." => "ส.",
"Jan." => "ม.ค.",
"Feb." => "ก.พ.",
"Mar." => "มี.ค.",
"Apr." => "เม.ย.",
"May." => "พ.ค.",
"Jun." => "มิ.ย.",
"Jul." => "ก.ค.",
"Aug." => "ส.ค.",
"Sep." => "ก.ย.",
"Oct." => "ต.ค.",
"Nov." => "พ.ย.",
"Dec." => "ธ.ค.",
"All day" => "ทั้งวัน",
"Missing fields" => "ช่องฟิลด์เกิดการสูญหาย",
"Title" => "ชื่อกิจกรรม",
"From Date" => "จากวันที่",
"From Time" => "ตั้งแต่เวลา",
"To Date" => "ถึงวันที่",
"To Time" => "ถึงเวลา",
"The event ends before it starts" => "วันที่สิ้นสุดกิจกรรมดังกล่าวอยู่ก่อนวันเริ่มต้น",
"There was a database fail" => "เกิดความล้มเหลวกับฐานข้อมูล",
"Week" => "สัปดาห์",
"Month" => "เดือน",
"List" => "รายการ",
"Today" => "วันนี้",
"Calendars" => "ปฏิทิน",
"Settings" => "ตั้งค่า",
"Your calendars" => "ปฏิทินของคุณ",
"CalDav Link" => "ลิงค์ CalDav",
"Share Calendar" => "เปิดแชร์ปฏิทิน",
"Download" => "ดาวน์โหลด",
"Edit" => "แก้ไข",
"Delete" => "ลบ",
"shared with you by" => "แชร์ให้คุณโดย",
"New calendar" => "สร้างปฏิทินใหม่",
"Edit calendar" => "แก้ไขปฏิทิน",
"Displayname" => "ชื่อที่ต้องการให้แสดง",
"Active" => "ใช้งาน",
"Calendar color" => "สีของปฏิทิน",
"Save" => "บันทึก",
"Submit" => "ส่งข้อมูล",
"Cancel" => "ยกเลิก",
"Edit an event" => "แก้ไขกิจกรรม",
"Export" => "ส่งออกข้อมูล",
"Eventinfo" => "ข้อมูลเกี่ยวกับกิจกรรม",
"Repeating" => "ทำซ้ำ",
"Alarm" => "แจ้งเตือน",
"Attendees" => "ผู้เข้าร่วมกิจกรรม",
"Share" => "แชร์",
"Title of the Event" => "ชื่อของกิจกรรม",
"Category" => "หมวดหมู่",
"Separate categories with commas" => "คั่นระหว่างรายการหมวดหมู่ด้วยเครื่องหมายจุลภาคหรือคอมม่า",
"Edit categories" => "แก้ไขหมวดหมู่",
"All Day Event" => "เป็นกิจกรรมตลอดทั้งวัน",
"From" => "จาก",
"To" => "ถึง",
"Advanced options" => "ตัวเลือกขั้นสูง",
"Location" => "สถานที่",
"Location of the Event" => "สถานที่จัดกิจกรรม",
"Description" => "คำอธิบาย",
"Description of the Event" => "คำอธิบายเกี่ยวกับกิจกรรม",
"Repeat" => "ทำซ้ำ",
"Advanced" => "ขั้นสูง",
"Select weekdays" => "เลือกสัปดาห์",
"Select days" => "เลือกวัน",
"and the events day of year." => "และวันที่มีเหตุการณ์เกิดขึ้นในปี",
"and the events day of month." => "และวันที่มีเหตุการณ์เกิดขึ้นในเดือน",
"Select months" => "เลือกเดือน",
"Select weeks" => "เลือกสัปดาห์",
"and the events week of year." => "และสัปดาห์ที่มีเหตุการณ์เกิดขึ้นในปี",
"Interval" => "ช่วงเวลา",
"End" => "สิ้นสุด",
"occurrences" => "จำนวนที่ปรากฏ",
"create a new calendar" => "สร้างปฏิทินใหม่",
"Import a calendar file" => "นำเข้าไฟล์ปฏิทิน",
"Please choose a calendar" => "กรุณาเลือกปฏิทิน",
"Name of new calendar" => "ชื่อของปฏิทิน",
"Take an available name!" => "เลือกชื่อที่ต้องการ",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "ปฏิทินชื่อดังกล่าวถูกใช้งานไปแล้ว หากคุณยังดำเนินการต่อไป ปฏิทินดังกล่าวนี้จะถูกผสานข้อมูลเข้าด้วยกัน",
"Import" => "นำเข้าข้อมูล",
"Close Dialog" => "ปิดกล่องข้อความโต้ตอบ",
"Create a new event" => "สร้างกิจกรรมใหม่",
"Share with:" => "แชร์ด้วย:",
"Shared with" => "แชร์ด้วย",
"Unshare" => "ยกเลิกการแชร์",
"Nobody" => "ไม่มีใคร",
"Shared via calendar" => "แชร์ผ่านทางปฏิทิน",
"NOTE: Actions on events shared via calendar will affect the entire calendar sharing." => "หมายเหตุ: การกระทำหรือกิจกรรมที่ได้รับการแชรผ่านทางปฏิทินจะมีผลกระทบกับการแชร์ปฏิทินทั้งหมด",
"View an event" => "ดูกิจกรรม",
"No categories selected" => "ยังไม่ได้เลือกหมวดหมู่",
"of" => "ของ",
"at" => "ที่",
"General" => "ทั่วไป",
"Timezone" => "โซนเวลา",
"Update timezone automatically" => "อัพเดทโซนเวลาอัตโนมัติ",
"Time format" => "รูปแบบเวลา",
"24h" => "24 ช.ม.",
"12h" => "12 ช.ม.",
"Start week on" => "เริ่มต้นสัปดาห์ด้วย",
"Cache" => "หน่วยความจำแคช",
"Clear cache for repeating events" => "ล้างข้อมูลในหน่วยความจำแคชสำหรับกิจกรรมที่ซ้ำซ้อน",
"URLs" => "URLs",
"Calendar CalDAV syncing addresses" => "ที่อยู่ที่ใช้สำหรับเชื่อมข้อมูลปฏิทิน CalDAV",
"more info" => "ข้อมูลเพิ่มเติม",
"Primary address (Kontact et al)" => "ที่อยู่หลัก (Kontact et al)",
"iOS/OS X" => "iOS/OS X",
"Read only iCalendar link(s)" => "อ่านเฉพาะลิงก์ iCalendar เท่านั้น"
);

==> owncloud-5.0.9.tgz: owncloud/apps/calendar/l10n/th_TH.php <==
<?php $TRANSLATIONS = array(
"Not all calendars are completely cached" => "ไม่ใช่ปฏิทินทั้งหมดที่จะถูกจัดเก็บข้อมูลไว้ในหน่วยความจำแคชอย่างสมบูรณ์",
"Everything seems to be completely cached" => "ทุกสิ่งทุกอย่างได้ถูกเก็บเข้าไปไว้ในหน่วยความจำแคชอย่างสมบูรณ์แล้ว",
"No calendars found." => "ไม่พบปฏิทินที่ต้องการ",
"No events found." => "ไม่พบกิจกรรมที่ต้องการ",
"Wrong calendar" => "ปฏิทินไม่ถูกต้อง",
"You do not have the permissions to edit this event." => "คุณไม่ได้รับสิทธิ์ให้แก้ไขกิจกรรมนี้",
"The file contained either no events or all events are already saved in your calendar." => "ไฟล์ดังกล่าวบรรจุข้อมูลกิจกรรมที่มีอยู่แล้วในปฏิทินของคุณ",
"events has been saved in the new calendar" => "กิจกรรมได้ถูกบันทึกไปไว้ในปฏิทินที่สร้างขึ้นใหม่แล้ว",
"Import failed" => "การนำเข้าข้อมูลล้มเหลว",
"events has been saved in your calendar" => "กิจกรรมได้ถูกบันทึกเข้าไปไว้ในปฏิทินของคุณแล้ว",
"New Timezone:" => "สร้างโซนเวลาใหม่:",
"Timezone changed" => "โซนเวลาถูกเปลี่ยนแล้ว",
"Invalid request" => "คำร้องขอไม่ถูกต้อง",
"Calendar" => "ปฏิทิน",
"Deletion failed" => "การลบทิ้งล้มเหลว",
"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}",
"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}",
"user" => "ผู้ใช้งาน",
"group" => "กลุ่มผู้ใช้งาน",
"Editable" => "สามารถแก้ไขได้",
"Shareable" => "สามารถแชร์ข้อมูลได้",
"Deletable" => "สามารถลบทิ้งได้",
"ddd" => "ddd",
"ddd M/d" => "ddd M/d",
"dddd M/d" => "dddd M/d",
"MMMM yyyy" => "MMMM yyyy",
"MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}" => "MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}",
"dddd, MMM d, yyyy" => "dddd, MMM d, yyyy",
"Sunday" => "วันอาทิตย์",
"Monday" => "วันจันทร์",
"Tuesday" => "วันอังคาร",
"Wednesday" => "วันพุธ",
"Thursday" => "วันพฤหัสบดี",
"Friday" => "วันศุกร์",
"Saturday" => "วันเสาร์",
"Sun." => "อา.",
"Mon." => "จ.",
"Tue." => "อ.",
"Wed." => "พ.",
"Thu." => "พฤ.",
"Fri." => "ศ.",
"Sat." => "ส.",
"January" => "มกราคม",
"February" => "กุมภาพันธ์",
"March" => "มีนาคม",
"April" => "เมษายน",
"May" => "พฤษภาคม",
"June" => "มิถุนายน",
"July" => "กรกฏาคม",
"August" => "สิงหาคม",
"September" => "กันยายน",
"October" => "ตุลาคม",
"November" => "พฤศจิกายน",
"December" => "ธันวาคม",
"Jan." => "ม.ค.",
"Feb." => "ก.พ.",
"Mar." => "มี.ค.",
"Apr." => "เม.ย.",
"May." => "พ.ค.",
"Jun." => "มิ.ย.",
"Jul." => "ก.ค.",
"Aug." => "ส.ค.",
"Sep." => "ก.ย.",
"Oct." => "ต.ค.",
"Nov." => "พ.ย.",
"Dec." => "ธ.ค.",
"All day" => "ทั้งวัน",
"New Calendar" => "สร้างปฏิทินใหม่",
"Missing or invalid fields" => "ช่องข้อมูลไม่ถูกต้องหรือเกิดการสูญหาย",
"Title" => "ชื่อกิจกรรม",
"From Date" => "จากวันที่",
"From Time" => "ตั้งแต่เวลา",
"To Date" => "ถึงวันที่",
"To Time" => "ถึงเวลา",
"The event ends before it starts" => "วันที่สิ้นสุดกิจกรรมดังกล่าวอยู่ก่อนวันเริ่มต้น",
"There was a database fail" => "เกิดความล้มเหลวกับฐานข้อมูล",
"Birthday" => "วันเกิด",
"Business" => "ธุรกิจ",
"Call" => "โทรติดต่อ",
"Clients" => "ลูกค้า",
"Deliverer" => "จัดส่ง",
"Holidays" => "วันหยุด",
"Ideas" => "ไอเดีย",
"Journey" => "การเดินทาง",
"Jubilee" => "งานเลี้ยง",
"Meeting" => "นัดประชุม",
"Other" => "อื่นๆ",
"Personal" => "ส่วนตัว",
"Projects" => "โครงการ",
"Questions" => "คำถาม",
"Work" => "งาน",
"by" => "โดย",
"unnamed" => "ไม่มีชื่อ",
"You do not have the permissions to update this calendar." => "คุณไม่ได้รับสิทธิ์ให้อัพเดทปฏิทินนี้",
"You do not have the permissions to delete this calendar." => "คุณไม่ได้รับสิทธิ์ให้ลบปฏิทินนี้ทิ้งไป",
"You do not have the permissions to add to this calendar." => "คุณไม่ได้รับสิทธิ์ให้เพิ่มปฏิทินนี้",
"You do not have the permissions to add events to this calendar." => "คุณไม่ได้รับสิทธิ์ให้เพิ่มกิจกรรมเข้าไปในปฏิทินนี้",
"You do not have the permissions to delete this event." => "คุณไม่ได้รับสิทธิ์ให้ลบกิจกรรมนี้",
"Busy" => "ไม่ว่าง",
"Public" => "สาธารณะ",
"Private" => "ส่วนตัว",
"Confidential" => "ความลับ",
"Does not repeat" => "ไม่ต้องทำซ้ำ",
"Daily" => "รายวัน",
"Weekly" => "รายสัปดาห์",
"Every Weekday" => "ทุกวันหยุด",
"Bi-Weekly" => "รายปักษ์",
"Monthly" => "รายเดือน",
"Yearly" => "รายปี",
"never" => "ไม่ต้องเลย",
"by occurrences" => "ตามจำนวนที่ปรากฏ",
"by date" => "ตามวันที่",
"by monthday" => "จากเดือน",
"by weekday" => "จากสัปดาห์",
"events week of month" => "สัปดาห์ที่มีกิจกรรมของเดือน",
"first" => "ลำดับแรก",
"second" => "ลำดับที่สอง",
"third" => "ลำดับที่สาม",
"fourth" => "ลำดับที่สี่",
"fifth" => "ลำดับที่ห้า",
"last" => "ลำดับสุดท้าย",
"by events date" => "ตามวันที่จัดกิจกรรม",
"by yearday(s)" => "ของเมื่อวานนี้",
"by weeknumber(s)" => "จากหมายเลขของสัปดาห์",
"by day and month" => "ตามวันและเดือน",
"Date" => "วันที่",
"Cal." => "คำนวณ",
"Week" => "สัปดาห์",
"Month" => "เดือน",
"List" => "รายการ",
"Today" => "วันนี้",
"Settings" => "ตั้งค่า",
"Your calendars" => "ปฏิทินของคุณ",
"CalDav Link" => "ลิงค์ CalDav",
"Share Calendar" => "เปิดแชร์ปฏิทิน",
"Download" => "ดาวน์โหลด",
"Edit" => "แก้ไข",
"Delete" => "ลบ",
"New calendar" => "สร้างปฏิทินใหม่",
"Edit calendar" => "แก้ไขปฏิทิน",
"Displayname" => "ชื่อที่ต้องการให้แสดง",
"Active" => "ใช้งาน",
"Calendar color" => "สีของปฏิทิน",
"Save" => "บันทึก",
"Submit" => "ส่งข้อมูล",
"Cancel" => "ยกเลิก",
"Edit an event" => "แก้ไขกิจกรรม",
"Export" => "ส่งออกข้อมูล",
"Eventinfo" => "ข้อมูลเกี่ยวกับกิจกรรม",
"Repeating" => "ทำซ้ำ",
"Alarm" => "แจ้งเตือน",
"Attendees" => "ผู้เข้าร่วมกิจกรรม",
"Share" => "แชร์",
"Title of the Event" => "ชื่อของกิจกรรม",
"Category" => "หมวดหมู่",
"Separate categories with commas" => "คั่นระหว่างรายการหมวดหมู่ด้วยเครื่องหมายจุลภาคหรือคอมม่า",
"Edit categories" => "แก้ไขหมวดหมู่",
"Access Class" => "เข้าเรียน",
"All Day Event" => "เป็นกิจกรรมตลอดทั้งวัน",
"From" => "จาก",
"To" => "ถึง",
"Advanced options" => "ตัวเลือกขั้นสูง",
"Location" => "สถานที่",
"Location of the Event" => "สถานที่จัดกิจกรรม",
"Description" => "คำอธิบาย",
"Description of the Event" => "คำอธิบายเกี่ยวกับกิจกรรม",
"Repeat" => "ทำซ้ำ",
"Advanced" => "ขั้นสูง",
"Select weekdays" => "เลือกสัปดาห์",
"Select days" => "เลือกวัน",
"and the events day of year." => "และวันที่มีเหตุการณ์เกิดขึ้นในปี",
"and the events day of month." => "และวันที่มีเหตุการณ์เกิดขึ้นในเดือน",
"Select months" => "เลือกเดือน",
"Select weeks" => "เลือกสัปดาห์",
"and the events week of year." => "และสัปดาห์ที่มีเหตุการณ์เกิดขึ้นในปี",
"Interval" => "ช่วงเวลา",
"End" => "สิ้นสุด",
"occurrences" => "จำนวนที่ปรากฏ",
"create a new calendar" => "สร้างปฏิทินใหม่",
"Import a calendar file" => "นำเข้าไฟล์ปฏิทิน",
"Please choose a calendar" => "กรุณาเลือกปฏิทิน",
"Name of new calendar" => "ชื่อของปฏิทิน",
"Take an available name!" => "เลือกชื่อที่ต้องการ",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "ปฏิทินชื่อดังกล่าวถูกใช้งานไปแล้ว หากคุณยังดำเนินการต่อไป ปฏิทินดังกล่าวนี้จะถูกผสานข้อมูลเข้าด้วยกัน",
"Remove all events from the selected calendar" => "ลบกิจกรรมทั้งหมดออกจากปฏิทินที่เลือกไว้",
"Import" => "นำเข้าข้อมูล",
"Close Dialog" => "ปิดกล่องข้อความโต้ตอบ",
"Create a new event" => "สร้างกิจกรรมใหม่",
"Share with:" => "แชร์ด้วย:",
"Shared with" => "แชร์ด้วย",
"Unshare" => "ยกเลิกการแชร์",
"Nobody" => "ไม่มีใคร",
"Shared via calendar" => "แชร์ผ่านทางปฏิทิน",
"NOTE: Actions on events shared via calendar will affect the entire calendar sharing." => "หมายเหตุ: การกระทำหรือกิจกรรมที่ได้รับการแชรผ่านทางปฏิทินจะมีผลกระทบกับการแชร์ปฏิทินทั้งหมด",
"View an event" => "ดูกิจกรรม",
"No categories selected" => "ยังไม่ได้เลือกหมวดหมู่",
"of" => "ของ",
"at" => "ที่",
"General" => "ทั่วไป",
"Timezone" => "โซนเวลา",
"Update timezone automatically" => "อัพเดทโซนเวลาอัตโนมัติ",
"Time format" => "รูปแบบเวลา",
"24h" => "24 ช.ม.",
"12h" => "12 ช.ม.",
"Start week on" => "เริ่มต้นสัปดาห์ด้วย",
"Cache" => "หน่วยความจำแคช",
"Clear cache for repeating events" => "ล้างข้อมูลในหน่วยความจำแคชสำหรับกิจกรรมที่ซ้ำซ้อน",
"URLs" => "URLs",
"Calendar CalDAV syncing addresses" => "ที่อยู่ที่ใช้สำหรับเชื่อมข้อมูลปฏิทิน CalDAV",
"more info" => "ข้อมูลเพิ่มเติม",
"Primary address (Kontact et al)" => "ที่อยู่หลัก (Kontact et al)",
"iOS/OS X" => "iOS/OS X",
"Read only iCalendar link(s)" => "อ่านเฉพาะลิงก์ iCalendar เท่านั้น"
);
